@@ -5,21 +5,28 @@
 
 from __future__ import division
 
+from concurrent.futures import Future
 from datetime import datetime
 import os
+import sys
+from threading import Thread
 import time
 
+import pytest
+from tornado.concurrent import Future as TornadoFuture
+
 from IPython import get_ipython
 from ipyparallel.client import client as clientmod
 from ipyparallel import error, AsyncHubResult, DirectView, Reference
+from ipyparallel.util import utc
 
 from .clienttest import ClusterTestCase, wait, add_engines, skip_without
 
-def setup():
-    add_engines(4, total=True)
-
+@pytest.mark.usefixtures('ipython')
 class TestClient(ClusterTestCase):
     
+    engine_count = 4
+    
     def test_ids(self):
         n = len(self.client.ids)
         self.add_engines(2)
@@ -293,7 +300,7 @@ class TestClient(ClusterTestCase):
         for rec in recs:
             recdict[rec['msg_id']] = rec
         
-        latest = datetime(1984,1,1)
+        latest = datetime(1984,1,1).replace(tzinfo=utc)
         for msg_id in hist:
             rec = recdict[msg_id]
             newt = rec['submitted']
@@ -482,7 +489,7 @@ class TestClient(ClusterTestCase):
         # ensure there are some tasks
         for i in range(5):
             self.client[:].apply_sync(lambda : 1)
-        self.client.wait(10)
+        assert self.client.wait(timeout=10)
         self._wait_for_idle()
         self.client.purge_results('all')
         self.assertEqual(len(self.client.results), 0, msg="Results not empty")
@@ -494,7 +501,7 @@ class TestClient(ClusterTestCase):
         # ensure there are some tasks
         for i in range(5):
             self.client[:].apply_sync(lambda : 1)
-        self.client.wait(10)
+        self.client.wait(timeout=10)
         self._wait_for_idle()
         self.client.purge_everything()
         # The client results
@@ -506,12 +513,18 @@ class TestClient(ClusterTestCase):
         # the hub results
         hist = self.client.hub_history()
         self.assertEqual(len(hist), 0, msg="hub history not empty")
-    
+
+    def test_activate_on_init(self):
+        ip = get_ipython()
+        magics = ip.magics_manager.magics
+        c = self.connect_client()
+        self.assertTrue('px' in magics['line'])
+        self.assertTrue('px' in magics['cell'])
+        c.close()
+
     def test_activate(self):
         ip = get_ipython()
         magics = ip.magics_manager.magics
-        self.assertTrue('px' in magics['line'])
-        self.assertTrue('px' in magics['cell'])
         v0 = self.client.activate(-1, '0')
         self.assertTrue('px0' in magics['line'])
         self.assertTrue('px0' in magics['cell'])
@@ -525,10 +538,23 @@ class TestClient(ClusterTestCase):
         ar = self.client[-1].apply_async(lambda : 1)
         self.client.wait_interactive()
         self.assertEqual(self.client.outstanding, set())
-    
+
+    def test_await_future(self):
+        f = Future()
+        def finish_later():
+            time.sleep(0.1)
+            f.set_result('future')
+        Thread(target=finish_later).start()
+        assert self.client.wait([f])
+        assert f.done()
+        assert f.result() == 'future'
+
     @skip_without('distributed')
-    def test_become_distributed(self):
-        executor = self.client.become_distributed()
+    @pytest.mark.skipif(
+        sys.version_info[:2] == (3, 4),
+        reason="become_dask doesn't work on Python 3.4")
+    def test_become_dask(self):
+        executor = self.client.become_dask()
         reprs = self.client[:].apply_sync(repr, Reference('distributed_worker'))
         for r in reprs:
             self.assertIn("Worker", r)
@@ -538,7 +564,8 @@ class TestClient(ClusterTestCase):
         self.assertEqual(tot.result(), 285)
 
         # cleanup
-        self.client.stop_distributed()
+        executor.shutdown()
+        self.client.stop_dask()
         ar = self.client[:].apply_async(lambda x: x, Reference('distributed_worker'))
         self.assertRaisesRemote(NameError, ar.get)
 
